from instrumental.plugins.nose.tag_test_cases import InstrumentalTagPlugin

class FakeTest(object):
    
    def __init__(self, id, address=None):
        self._id = id
        if address is not None:
            self.address = lambda: address
    
    def id(self):
        return self._id
    
class TestPluginInstrumentalTag(object):
    
    def _makeOne(self):
        return InstrumentalTagPlugin()
    
    def test_startTest_without_address(self):
        test = FakeTest('some_fake_test')
        
        plugin = self._makeOne()
        plugin.startTest(test)
            
        from instrumental.api import Coverage
        cov = Coverage(None)
        assert cov.recorder.tag == 'some_fake_test'
    
    def test_startTest_with_address(self):
        test = FakeTest('some_fake_test',
                        ['filename.py', 'SomeTestClass', 'some_fake_test'])
        
        plugin = self._makeOne()
        plugin.startTest(test)
            
        from instrumental.api import Coverage
        cov = Coverage(None)
        assert cov.recorder.tag == 'SomeTestClass:some_fake_test', cov.recorder.tag



# 
# Copyright (C) 2012  Jason Michalski

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
import inspect

def exec_f(object_, globals_=None, locals_=None):
    if not globals_ and not locals_:
       frame = inspect.stack()[1][0]
       globals_ = frame.f_globals
       locals_ = frame.f_locals
    elif globals_ and not locals_:
        locals_ = globals_
    exec object_ in globals_, locals_

execfile = execfile
